==> chaosmesh-model-6.0.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StressChaosFluentImpl<A extends StressChaosFluent<A>> extends BaseFluent<A> implements StressChaosFluent<A>{
  public StressChaosFluentImpl() {
  }
  public StressChaosFluentImpl(StressChaos instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private StressChaosSpecBuilder spec;
  private StressChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public StressChaosFluent.MetadataNested<A> withNewMetadata() {
    return new StressChaosFluentImpl.MetadataNestedImpl();
  }
  public StressChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new StressChaosFluentImpl.MetadataNestedImpl(item);
  }
  public StressChaosFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public StressChaosFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public StressChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public StressChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public StressChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(StressChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new StressChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public StressChaosFluent.SpecNested<A> withNewSpec() {
    return new StressChaosFluentImpl.SpecNestedImpl();
  }
  public StressChaosFluent.SpecNested<A> withNewSpecLike(StressChaosSpec item) {
    return new StressChaosFluentImpl.SpecNestedImpl(item);
  }
  public StressChaosFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public StressChaosFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new StressChaosSpecBuilder().build());
  }
  public StressChaosFluent.SpecNested<A> editOrNewSpecLike(StressChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public StressChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public StressChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(StressChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new StressChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public StressChaosFluent.StatusNested<A> withNewStatus() {
    return new StressChaosFluentImpl.StatusNestedImpl();
  }
  public StressChaosFluent.StatusNested<A> withNewStatusLike(StressChaosStatus item) {
    return new StressChaosFluentImpl.StatusNestedImpl(item);
  }
  public StressChaosFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public StressChaosFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new StressChaosStatusBuilder().build());
  }
  public StressChaosFluent.StatusNested<A> editOrNewStatusLike(StressChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StressChaosFluentImpl that = (StressChaosFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<StressChaosFluent.MetadataNested<N>> implements StressChaosFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) StressChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends StressChaosSpecFluentImpl<StressChaosFluent.SpecNested<N>> implements StressChaosFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(StressChaosSpec item) {
      this.builder = new StressChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new StressChaosSpecBuilder(this);
    }
    StressChaosSpecBuilder builder;
    public N and() {
      return (N) StressChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends StressChaosStatusFluentImpl<StressChaosFluent.StatusNested<N>> implements StressChaosFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(StressChaosStatus item) {
      this.builder = new StressChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new StressChaosStatusBuilder(this);
    }
    StressChaosStatusBuilder builder;
    public N and() {
      return (N) StressChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StressChaosFluentImpl<A extends StressChaosFluent<A>> extends BaseFluent<A> implements StressChaosFluent<A>{
  public StressChaosFluentImpl() {
  }
  public StressChaosFluentImpl(StressChaos instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private StressChaosSpecBuilder spec;
  private StressChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public StressChaosFluentImpl.MetadataNested<A> withNewMetadata() {
    return new StressChaosFluentImpl.MetadataNestedImpl();
  }
  public StressChaosFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new StressChaosFluentImpl.MetadataNestedImpl(item);
  }
  public StressChaosFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public StressChaosFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public StressChaosFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public StressChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public StressChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(StressChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new StressChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public StressChaosFluentImpl.SpecNested<A> withNewSpec() {
    return new StressChaosFluentImpl.SpecNestedImpl();
  }
  public StressChaosFluentImpl.SpecNested<A> withNewSpecLike(StressChaosSpec item) {
    return new StressChaosFluentImpl.SpecNestedImpl(item);
  }
  public StressChaosFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public StressChaosFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new StressChaosSpecBuilder().build());
  }
  public StressChaosFluentImpl.SpecNested<A> editOrNewSpecLike(StressChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public StressChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public StressChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(StressChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new StressChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public StressChaosFluentImpl.StatusNested<A> withNewStatus() {
    return new StressChaosFluentImpl.StatusNestedImpl();
  }
  public StressChaosFluentImpl.StatusNested<A> withNewStatusLike(StressChaosStatus item) {
    return new StressChaosFluentImpl.StatusNestedImpl(item);
  }
  public StressChaosFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public StressChaosFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new StressChaosStatusBuilder().build());
  }
  public StressChaosFluentImpl.StatusNested<A> editOrNewStatusLike(StressChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StressChaosFluentImpl that = (StressChaosFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<StressChaosFluentImpl.MetadataNested<N>> implements StressChaosFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) StressChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends StressChaosSpecFluentImpl<StressChaosFluentImpl.SpecNested<N>> implements StressChaosFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(StressChaosSpec item) {
      this.builder = new StressChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new StressChaosSpecBuilder(this);
    }
    StressChaosSpecBuilder builder;
    public N and() {
      return (N) StressChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends StressChaosStatusFluentImpl<StressChaosFluentImpl.StatusNested<N>> implements StressChaosFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(StressChaosStatus item) {
      this.builder = new StressChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new StressChaosStatusBuilder(this);
    }
    StressChaosStatusBuilder builder;
    public N and() {
      return (N) StressChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
